OpenSCAP Report Generator
=========================

.. toctree::
    :maxdepth: 2
    :glob:
    :caption: User's Manual

    manual/installation*
    manual/usage*
    manual/*

.. toctree::
    :maxdepth: 1
    :glob:
    :caption: Man Page

    oscap-report.1.rst

.. toctree::
    :maxdepth: 1
    :glob:
    :caption: Modules API

    modules/modules.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
